ImageItemContent class

Inheritance

Constructors

ImageItemContent({String? url, String? assetName, String? semanticLabel, bool excludeFromSemantics = false, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit fit = BoxFit.cover, ImageRepeat repeat = ImageRepeat.noRepeat, bool matchTextDirection = false, bool gaplessPlayback = false, bool isAntiAlias = false, FilterQuality filterQuality = FilterQuality.low})
ImageItemContent.fromJson(Map<String, dynamic> json)
factory

Properties

assetName ↔ String?
getter/setter pair
color ↔ Color?
getter/setter pair
colorBlendMode ↔ BlendMode?
getter/setter pair
excludeFromSemantics ↔ bool
getter/setter pair
filterQuality ↔ FilterQuality
getter/setter pair
fit ↔ BoxFit
getter/setter pair
gaplessPlayback ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
image → ImageProvider<Object>
no setter
isAntiAlias ↔ bool
getter/setter pair
matchTextDirection ↔ bool
getter/setter pair
repeat ↔ ImageRepeat
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel ↔ String?
getter/setter pair
url ↔ String?
getter/setter pair
width ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRes({String? url, String? assetName}) → void
toJson() → Map<String, dynamic>
  • to json
  • 转 json
  • override
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited